/*
 * gradtest.c
 * Shows edge transparency problems when using SDL_DisplayFormat
 * (note, we are not mentionning SDL_DisplayFormatAlpha!)
 *
 * Samuel Hart - Code is placed in Public Domain
 */

#include <stdio.h>
#include <stdlib.h>

#include "SDL.h"
#include "SDL_image.h"

#define BPP 0
#define RESX 400
#define RESY 200

int main(void)
{
	SDL_Surface *screen;
	SDL_Surface *pic1, *pic2, *pictemp;
	SDL_Rect dest;
	SDL_Event event;
        int i;
	Uint32 video_flags, lib_flags;

	lib_flags = SDL_INIT_VIDEO;
	video_flags = SDL_ANYFORMAT;

	if (SDL_Init (lib_flags) < 0) {
		fprintf (stderr, "Couldn't initialize SDL: %s\n", SDL_GetError ());
		exit(EXIT_FAILURE);
	}
	screen = SDL_SetVideoMode (RESX, RESY, BPP, video_flags);
	SDL_ShowCursor(1);
	SDL_WM_SetCaption ("Left is display format, right isn't", "gradtest");

        /* Note there is no error checking */

        /* First one (on the left) will be set to the display's format */
        pictemp = IMG_Load("img.png");
        pic1 = SDL_DisplayFormat(pictemp);
        SDL_FreeSurface(pictemp);

        /* Second one (on the right) will not be set to display's format */
        pic2 = IMG_Load("img.png");

        /* Blit the two */
        dest.y = 0;
        dest.x = 0;
        dest.w = pic1->w;
        dest.h = pic1->h;
        SDL_BlitSurface(pic1, NULL, screen, &dest);

        dest.x += dest.w;
        dest.w = pic2->w;
        dest.h = pic2->w;
        SDL_BlitSurface(pic2, NULL, screen, &dest);

	SDL_UpdateRect (screen, 0, 0, 0, 0);

        /* Loop, waiting for escape */
	while (SDL_PollEvent(&event) >= 0)
	{
		if (event.type & (SDL_KEYUP | SDL_KEYDOWN))
		{
			Uint8 *keys = SDL_GetKeyState(&i);
			/* Press ESC to exit */
			if(keys[SDLK_ESCAPE])
				break;
		}
	}

	SDL_FreeSurface(pic1);
        SDL_FreeSurface(pic2);

        return(EXIT_SUCCESS);
}
